aboutsummaryrefslogtreecommitdiff
path: root/src/libjin/Graphics/je_bitmap.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/libjin/Graphics/je_bitmap.h')
-rw-r--r--src/libjin/Graphics/je_bitmap.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/libjin/Graphics/je_bitmap.h b/src/libjin/Graphics/je_bitmap.h
index 92ab836..eeb065e 100644
--- a/src/libjin/Graphics/je_bitmap.h
+++ b/src/libjin/Graphics/je_bitmap.h
@@ -7,9 +7,9 @@
#include "../math/je_vector2.hpp"
#include "je_color.h"
-namespace jin
+namespace JinEngine
{
- namespace graphics
+ namespace Graphics
{
///
/// A RGBA32 bitmap.
@@ -145,7 +145,7 @@ namespace jin
///
/// @return Size of bitmap.
///
- inline math::Vector2<int> getSize() const { return math::Vector2<int>(width, height); }
+ inline Math::Vector2<int> getSize() const { return Math::Vector2<int>(width, height); }
protected:
///
@@ -166,8 +166,8 @@ namespace jin
};
- } // namespace graphics
-} // namespace jin
+ } // namespace Graphics
+} // namespace JinEngine
#endif
#endif \ No newline at end of file